@@ -5,7 +5,7 @@ use strict;
 use warnings; no warnings qw(void once uninitialized numeric redefine);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.003_001';
+our $VERSION   = '1.003_002';
 our @EXPORT_OK = qw< mkopt mkopt_hash _croak _carp >;
 
 sub _croak ($;@) { require Carp; my $fmt = shift; @_ = sprintf($fmt, @_); goto \&Carp::croak }
@@ -23,13 +23,13 @@ my $_process_optlist = sub
 		
 		($name =~ m{\A\!(/.+/[msixpodual]*)\z}) ?
 			do {
-				my @not = $class->_exporter_expand_regexp($1, $value, $global_opts);
+				my @not = $class->_exporter_expand_regexp("$1", $value, $global_opts);
 				++$not_want->{$_->[0]} for @not;
 			} :
 		($name =~ m{\A\!(.+)\z}) ?
 			(++$not_want->{$1}) :
 		($name =~ m{\A[:-](.+)\z}) ?
-			push(@$opts, $class->_exporter_expand_tag($1, $value, $global_opts)) :
+			push(@$opts, $class->_exporter_expand_tag("$1", $value, $global_opts)) :
 		($name =~ m{\A/.+/[msixpodual]*\z}) ?
 			push(@$opts, $class->_exporter_expand_regexp($name, $value, $global_opts)) :
 		# else ?
